# WavingHands
P2P Multiplayer Python implementation of Richard Bartle's Waving Hands (very WIP and buggy right now!

This code was originally written in 2020 and I've learned a lot since then.

### Development

Setup your preferred python environment first:

    python -m venv venv
    source venv/bin/activate

Then do a developer install. This will give you the `waving-hands` command you can use to start the client/server:

    python setup.py develop
    waving-hands


### Testing

Use pytest for testing:

    pip install pytest
    pytest
